@@ -1,8 +1,10 @@
-from django.conf.urls.defaults import include, patterns, url
+from django.conf.urls import include, patterns, url
 
 from .. import admin
 from ..views import login
 
+admin.autodiscover()
+
 
 urlpatterns = patterns(
     '',
